summaryrefslogtreecommitdiffstats
path: root/src/include/list.h
diff options
context:
space:
mode:
authorPatrick Rudolph <patrick.rudolph@9elements.com>2018-04-03 09:57:33 +0200
committerPatrick Georgi <pgeorgi@google.com>2018-04-30 09:33:32 +0000
commit666c172d385823eefdfeb99ae3a4c20fd1b711f9 (patch)
tree8d21e2083f19171688181d20baea09a6b78b6bd8 /src/include/list.h
parent67aca3e7dc05f0f982a50c7e8edb91a03d573687 (diff)
downloadcoreboot-666c172d385823eefdfeb99ae3a4c20fd1b711f9.tar.gz
coreboot-666c172d385823eefdfeb99ae3a4c20fd1b711f9.tar.bz2
coreboot-666c172d385823eefdfeb99ae3a4c20fd1b711f9.zip
lib/devicetree: Integrate flattened devicetree support
* Adapt to coreboot coding style. * Use coreboot's endian conversion functions. * Fix header and header guards. * Get rid of unused functions. * Add Kconfig to build it on ramstage. * Replace size32 with ALIGN_UP and DIV_ROUND_UP. * Add NULL pointer checks * Convert constants to defines Required for Cavium's BDK and uImage FIT support. Change-Id: I6e6cd9f78fb402bd54d684097326d26eb78d552a Signed-off-by: Patrick Rudolph <patrick.rudolph@9elements.com> Reviewed-on: https://review.coreboot.org/25523 Tested-by: build bot (Jenkins) <no-reply@coreboot.org> Reviewed-by: Julius Werner <jwerner@chromium.org>
Diffstat (limited to 'src/include/list.h')
-rw-r--r--src/include/list.h32
1 files changed, 15 insertions, 17 deletions
diff --git a/src/include/list.h b/src/include/list.h
index 084c8f015f88..201a8d39a823 100644
--- a/src/include/list.h
+++ b/src/include/list.h
@@ -1,8 +1,8 @@
/*
* Copyright 2012 Google Inc.
+ * Copyright 2018-present Facebook, Inc.
*
- * See file CREDITS for list of people who contributed to this
- * project.
+ * Taken from depthcharge: src/base/list.h
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License as
@@ -15,25 +15,23 @@
* GNU General Public License for more details.
*/
-#ifndef __BASE_LIST_H__
-#define __BASE_LIST_H__
+#ifndef __LIST_H__
+#define __LIST_H__
#include <stddef.h>
#include <stdint.h>
-#include "base/container_of.h"
+struct list_node {
+ struct list_node *next;
+ struct list_node *prev;
+};
-typedef struct ListNode {
- struct ListNode *next;
- struct ListNode *prev;
-} ListNode;
-
-// Remove ListNode node from the doubly linked list it's a part of.
-void list_remove(ListNode *node);
-// Insert ListNode node after ListNode after in a doubly linked list.
-void list_insert_after(ListNode *node, ListNode *after);
-// Insert ListNode node before ListNode before in a doubly linked list.
-void list_insert_before(ListNode *node, ListNode *before);
+// Remove list_node node from the doubly linked list it's a part of.
+void list_remove(struct list_node *node);
+// Insert list_node node after list_node after in a doubly linked list.
+void list_insert_after(struct list_node *node, struct list_node *after);
+// Insert list_node node before list_node before in a doubly linked list.
+void list_insert_before(struct list_node *node, struct list_node *before);
#define list_for_each(ptr, head, member) \
for ((ptr) = container_of((head).next, typeof(*(ptr)), member); \
@@ -41,4 +39,4 @@ void list_insert_before(ListNode *node, ListNode *before);
(ptr) = container_of((ptr)->member.next, \
typeof(*(ptr)), member))
-#endif /* __BASE_LIST_H__ */
+#endif /* __LIST_H__ */